@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   ILK   - Tilburg University
   CLST  - Radboud University
   CLiPS - University of Antwerp
@@ -51,6 +51,7 @@ namespace Timbl {
   public:
     bool SetOption( const std::string& );
     xmlNode *settingsToXml() const;
+    nlohmann::json settings_to_JSON() const;
     bool ShowWeights( std::ostream& ) const;
     bool Verbosity( VerbosityFlags v ) const {
       return verbosity & v; };
@@ -69,8 +70,10 @@ namespace Timbl {
     };
     WeightType CurrentWeighting() const { return Weighting; };
     InputFormatType InputFormat() const { return input_format; };
-    bool connectToSocket( std::ostream * );
+    bool connectToSocket( std::ostream *, bool = false );
     std::ostream *sock_os;
+    bool sock_is_json;
+    mutable nlohmann::json last_error;
     int getOcc() const { return doOcc; };
   protected:
     explicit MBLClass( const std::string& = "" );
