@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   ILK   - Tilburg University
   CLST  - Radboud University
   CLiPS - University of Antwerp
@@ -63,20 +63,34 @@ namespace Timbl {
       beam(0),
       norm(unknownNorm),
       factor(0.0),
+      best_target(0),
       targets(0)
 	{};
     ~resultStore();
     bool reset( int, normType, double, const Target * );
     void clear();
-    void addConstant( const ValueDistribution * );
-    void addTop( const ValueDistribution * );
-    void addDisposable( ValueDistribution * );
+    void addConstant( const ValueDistribution *, const TargetValue * );
+    void addTop( const ValueDistribution *, const TargetValue * );
+    void addDisposable( ValueDistribution *, const TargetValue * );
     const WValueDistribution *getResultDist();
     std::string getResult();
     void prepare();
     void normalize();
+    double confidence() const {
+      if ( dist ){
+	return dist->Confidence( best_target );
+      }
+      else {
+	return 0.0;
+      }
+    };
     double confidence( const TargetValue* tv ) const {
-      return dist->Confidence( tv );
+      if ( dist ){
+	return dist->Confidence( tv );
+      }
+      else {
+	return 0.0;
+      }
     };
   private:
     resultStore( const resultStore& ); // inhibit copies
@@ -88,6 +102,7 @@ namespace Timbl {
     int beam;
     normType norm;
     double factor;
+    const TargetValue *best_target;
     const Target *targets;
     std::string topCache;
     std::string resultCache;
@@ -160,11 +175,14 @@ namespace Timbl {
     bool GetWeights( const std::string&, WeightType );
     bool GetCurrentWeights( std::vector<double>& );
     xmlNode *weightsToXML();
+    nlohmann::json weights_to_JSON();
     bool ShowOptions( std::ostream& );
     bool ShowSettings( std::ostream& );
     xmlNode *settingsToXML();
+    nlohmann::json settings_to_JSON();
     bool showBestNeighbors( std::ostream& ) const;
     xmlNode *bestNeighborsToXML() const;
+    nlohmann::json best_neighbors_to_JSON() const;
     bool showStatistics( std::ostream& ) const;
     void showInputFormat( std::ostream& ) const;
     const std::string& ExpName() const { return exp_name; };
@@ -173,8 +191,12 @@ namespace Timbl {
     bool Classify( const std::string& , std::string&, double& );
     bool Classify( const std::string& , std::string&, std::string&, double& );
     size_t matchDepth() const { return match_depth; };
+    double confidence() const { return bestResult.confidence(); };
     bool matchedAtLeaf() const { return last_leaf; };
 
+    nlohmann::json classify_to_JSON( const std::string& );
+    nlohmann::json classify_to_JSON( const std::vector<std::string>& );
+
     virtual AlgorithmType Algorithm() const = 0;
     const TargetValue *Classify( const std::string& Line,
 				 const ValueDistribution *& db,
