@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   ILK   - Tilburg University
   CLST  - Radboud University
   CLiPS - University of Antwerp
@@ -35,11 +35,13 @@
 #include "timbl/Instance.h"
 #include "timbl/neighborSet.h"
 #include "ticcutils/XMLtools.h"
+#include "ticcutils/json.hpp"
 #include "timbl/BestArray.h"
 
 namespace Timbl {
   using namespace std;
   using namespace Common;
+  using namespace nlohmann;
 
   BestRec::BestRec():
     bestDistance( 0.0 )
@@ -210,8 +212,9 @@ namespace Timbl {
       ++k;
       if ( _storeInstances ){
 	size_t totalBests = best->totalBests();
-	if ( totalBests == 0 )
+	if ( totalBests == 0 ){
 	  break; // TRIBL algorithms do this!
+	}
 	xmlNode *nbs = TiCC::XmlNewChild( top, "neighbors" );
 	TiCC::XmlSetAttribute( nbs,
 			       "k",
@@ -222,24 +225,27 @@ namespace Timbl {
 	TiCC::XmlSetAttribute( nbs,
 			       "distance",
 			       TiCC::toString( best->bestDistance ) );
-	if ( maxBests < totalBests )
+	if ( maxBests < totalBests ){
 	  TiCC::XmlSetAttribute( nbs,
 				 "limited",
 				 TiCC::toString( maxBests ) );
+	}
 	for ( unsigned int m=0; m < best->bestInstances.size(); ++m ){
 	  xmlNode *nb = TiCC::XmlNewChild( nbs, "neighbor" );
 	  TiCC::XmlNewTextChild( nb,
 				 "instance",
 				 best->bestInstances[m] );
-	  if ( _showDb )
+	  if ( _showDb ){
 	    TiCC::XmlNewTextChild( nb,
 				   "distribution",
 				   best->bestDistributions[m]->DistToString() );
+	  }
 	}
       }
       else {
-	if ( best->aggregateDist.ZeroDist() )
+	if ( best->aggregateDist.ZeroDist() ){
 	  break;
+	}
 	xmlNode *nbs = TiCC::XmlNewChild( top, "neighbors" );
 	TiCC::XmlSetAttribute( nbs, "k", TiCC::toString(k) );
 	if ( _showDb ){
@@ -257,34 +263,116 @@ namespace Timbl {
     return top;
   }
 
+
+  json neighbor_to_json( const string& nb, const string& db ){
+    json result;
+    result["instance"] = nb;
+    if ( !db.empty() ){
+      result["distribution"] = db;
+    }
+    return result;
+  }
+
+  json BestArray::record_to_json( const BestRec *best, size_t k ) const {
+    json result;
+    if ( _storeInstances ){
+      size_t totalBests = best->totalBests();
+      if ( totalBests > 0 ){
+	// TRIBL algorithms returns 0 this!
+	result["k"] = k;
+	result["total"] = totalBests;
+	result["distance"] = best->bestDistance;
+	if ( maxBests < totalBests ){
+	  result["limited"] = maxBests;
+	}
+	if ( best->bestInstances.size() == 0 ){
+	}
+	else if ( best->bestInstances.size() == 1 ){
+	  string db;
+	  if ( _showDb ){
+	    db = best->bestDistributions[0]->DistToString();
+	  }
+	  result["neighbor"] = neighbor_to_json( best->bestInstances[0], db );
+	}
+	else {
+	  json arr = json::array();
+	  for ( unsigned int m=0; m < best->bestInstances.size(); ++m ){
+	    string db;
+	    if ( _showDb ){
+	      db = best->bestDistributions[m]->DistToString();
+	    }
+	    arr.push_back( neighbor_to_json( best->bestInstances[m], db ) );
+	  }
+	  result["neighbor"] = arr;
+	}
+      }
+    }
+    else {
+      if ( !best->aggregateDist.ZeroDist() ){
+	result["k"] = k;
+	if ( _showDb ){
+	  result["distribution"] = best->aggregateDist.DistToString();
+	}
+	if ( _showDi ){
+	  result["distance"] = best->bestDistance;
+	}
+      }
+    }
+    return result;
+  }
+
+  json BestArray::to_JSON() const {
+    json result;
+    if ( bestArray.size() == 0 ){
+      return result; // empty
+    }
+    else if ( bestArray.size() == 1 ){
+      result = record_to_json( bestArray[0], 1 );
+      return result;
+    }
+    else {
+      result = json::array();
+      size_t k = 0;
+      for ( auto const& best : bestArray ){
+	result.push_back( record_to_json( best, ++k) );
+      }
+    }
+    return result;
+  }
+
   ostream& operator<< ( ostream& os, const BestArray& bA ){
     size_t k = 0;
     for ( auto const& best : bA.bestArray ){
       ++k;
       if ( bA._storeInstances ){
 	size_t totalBests = best->totalBests();
-	if ( totalBests == 0 )
+	if ( totalBests == 0 ){
 	  break; // TRIBL algorithms do this!
+	}
 	os << "# k=" << k << ", " << totalBests
 	   <<  " Neighbor(s) at distance: ";
 	int OldPrec = os.precision(DBL_DIG-1);
 	os.setf(ios::showpoint);
 	os << "\t" << best->bestDistance;
 	os.precision(OldPrec);
-	if ( bA.maxBests <= best->bestInstances.size() )
+	if ( bA.maxBests <= best->bestInstances.size() ){
 	  os << " (only " << bA.maxBests << " shown)";
+	}
 	os << endl;
 	for ( unsigned int m=0; m < best->bestInstances.size(); ++m ){
 	  os << "#\t" << best->bestInstances[m];
-	  if ( bA._showDb )
+	  if ( bA._showDb ){
 	    os << best->bestDistributions[m]->DistToString() << endl;
-	  else
+	  }
+	  else {
 	    os << " -*-" << endl;
+	  }
 	}
       }
       else {
-	if ( best->aggregateDist.ZeroDist() )
+	if ( best->aggregateDist.ZeroDist() ){
 	  break;
+	}
 	os << "# k=" << k << "\t";
 	if ( bA._showDb ){
 	  os << best->aggregateDist.DistToString();
