@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   ILK   - Tilburg University
   CLST  - Radboud University
   CLiPS - University of Antwerp
@@ -35,10 +35,12 @@ namespace Common {
 
   string VersionInfo( bool full ){
     // obsolete
-    if ( full )
+    if ( full ){
       return BuildInfo();
-    else
+    }
+    else {
       return Version();
+    }
   }
   string Version() { return VERSION; }
   string VersionName() { return PACKAGE_STRING; }
