@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   ILK   - Tilburg University
   CLST  - Radboud University
   CLiPS - University of Antwerp
@@ -109,8 +109,9 @@ namespace Timbl {
     while ( pnt ) {
       if ( pnt->link || pnt->FValue ){
 	os << pnt->FValue;
-	if ( pnt->TValue )
+	if ( pnt->TValue ){
 	  os << "(" << pnt->TValue << ")" ;
+	}
 	if ( pnt->TDistribution ){
 	  os << pnt->TDistribution ;
 	}
@@ -120,8 +121,9 @@ namespace Timbl {
 	  os << pnt->link;
 	  IBtree_Indent--;
 	}
-	else
+	else {
 	  os << endl;
+	}
       }
       else {
 	if ( pnt->TValue ){
@@ -139,8 +141,9 @@ namespace Timbl {
 	os << endl;
       }
       if (pnt->next){
-	for ( int j=0; j<IBtree_Indent; ++j )
+	for ( int j=0; j<IBtree_Indent; ++j ){
 	  os << "\t";
+	}
       }
       pnt = pnt->next;
     }
@@ -148,10 +151,12 @@ namespace Timbl {
   }
 
   ostream &operator<<( ostream &os, const IBtree *grap ){
-    if ( grap )
+    if ( grap ){
       os << *grap;
-    else
+    }
+    else {
       os << "null";
+    }
     return os;
   }
 
@@ -162,10 +167,12 @@ namespace Timbl {
   }
 
   ostream& operator<<( ostream &os, const InstanceBase_base *ib ){
-    if ( ib )
+    if ( ib ){
       os << *ib;
-    else
+    }
+    else {
       os << "empty INSTANCE BASE";
+    }
     return os;
   }
 
@@ -191,8 +198,9 @@ namespace Timbl {
 	  os << pnt->FValue << " ";
 	  write_tree( os, pnt );
 	  pnt = pnt->next;
-	  if ( pnt )
+	  if ( pnt ){
 	    os << ",";
+	  }
 	}
 	os << "]\n";
       }
@@ -220,8 +228,9 @@ namespace Timbl {
 	  os << pnt->FValue->Index();
 	  write_tree_hashed( os, pnt );
 	  pnt = pnt->next;
-	  if ( pnt )
+	  if ( pnt ){
 	    os << ",";
+	  }
 	}
 	os << "]\n";
       }
@@ -236,8 +245,9 @@ namespace Timbl {
   }
 
   const TargetValue *InstanceBase_base::TopTarget( bool &tie ) {
-    if ( !DefaultsValid || !DefAss )
+    if ( !DefaultsValid || !DefAss ){
       TopT = 0;
+    }
     if ( TopT == 0 ){
       if ( !TopDistribution ){
 	// added to satisfy scan-build
@@ -264,8 +274,9 @@ namespace Timbl {
 	os << pnt->FValue;
 	write_tree( os, pnt );
 	pnt = pnt->next;
-	if ( pnt )
+	if ( pnt ){
 	  os << ",";
+	}
       }
       os << "]\n";
     }
@@ -307,18 +318,23 @@ namespace Timbl {
     TiCC::XmlSetAttribute( nodes, "nodecount", TiCC::toString( cnt ) );
     while ( pnt ){
       xmlNode *node = TiCC::XmlNewChild( nodes, "node" );
-      if ( pnt->FValue )
+      if ( pnt->FValue ){
 	xmlAddChild( node, to_node( pnt->FValue ) );
-      if ( pnt->TValue )
-	xmlAddChild( node, to_node( pnt->TValue ) );
-      if ( pnt->link ){
-	if ( pnt->link->FValue )
-	  xmlAddChild( node, to_xml(pnt->link) );
-	else if ( pnt->link->TDistribution )
-	  xmlAddChild( node, to_node( pnt->link->TDistribution ) );
       }
-      else if ( pnt->TDistribution )
+      if ( pnt->TValue ){
+	xmlAddChild( node, to_node( pnt->TValue ) );
+      }
+      if ( pnt->link ){
+	if ( pnt->link->FValue ){
+	  xmlAddChild( node, to_xml(pnt->link) );
+	}
+	else if ( pnt->link->TDistribution ){
+	  xmlAddChild( node, to_node( pnt->link->TDistribution ) );
+	}
+      }
+      else if ( pnt->TDistribution ){
 	xmlAddChild( node, to_node( pnt->TDistribution ) );
+      }
       pnt = pnt->next;
     }
     return nodes;
@@ -332,8 +348,9 @@ namespace Timbl {
 		 TiCC::XmlNewComment( "Version " + TiCC::toString(Version) ) );
     bool dummy;
     xmlAddChild( root, to_node( TopTarget( dummy ) ) );
-    if ( PersistentDistributions )
+    if ( PersistentDistributions ){
       xmlAddChild( root, to_node( TopDistribution ) );
+    }
     IBtree *pnt = InstBase;
     xmlNode *tree = to_xml( pnt );
     xmlAddChild( root, tree );
@@ -373,8 +390,9 @@ namespace Timbl {
 	    while ( pnt ){
 	      os << pnt->FValue;
 	      pnt = pnt->next;
-	      if ( pnt )
+	      if ( pnt ){
 		os << " ";
+	      }
 	    }
 	    os << " >" << endl;
 	  }
@@ -390,12 +408,14 @@ namespace Timbl {
 		  Hash::StringHash *feats ){
     int Size = cats->NumOfEntries();
     os << "Classes" << endl;
-    for ( int i=1; i <= Size; ++i )
+    for ( int i=1; i <= Size; ++i ){
       os << i << "\t" << cats->ReverseLookup( i ) << endl;
+    }
     Size = feats->NumOfEntries();
     os << "Features" << endl;
-    for ( int i=1; i <= Size; ++i )
+    for ( int i=1; i <= Size; ++i ){
       os << i << "\t" << feats->ReverseLookup( i ) << endl;
+    }
     os << endl;
   }
 
@@ -418,8 +438,9 @@ namespace Timbl {
 	os << pnt->FValue->Index();
 	write_tree_hashed( os, pnt );
 	pnt = pnt->next;
-	if ( pnt )
+	if ( pnt ){
 	  os << ",";
+	}
       }
       os << "]\n";
     }
@@ -475,8 +496,9 @@ namespace Timbl {
 					 vector<Feature*>& Feats,
 					 Target *Targ,
 					 int level ){
-    if ( !is )
+    if ( !is ){
       return NULL;
+    }
     IBtree *result = new IBtree();
     ++ibCount;
     string buf;
@@ -505,8 +527,9 @@ namespace Timbl {
       }
       // also we have to update the targetinformation of the featurevalue
       // so we can recalculate the statistics later on.
-      if ( result->FValue->ValFreq() > 0 )
+      if ( result->FValue->ValFreq() > 0 ){
 	result->FValue->ReconstructDistribution( *(result->TDistribution) );
+      }
     }
     if ( look_ahead(is) == '[' ){
       result->link = read_list( is, Feats, Targ, level+1 );
@@ -519,8 +542,9 @@ namespace Timbl {
       result->link = new IBtree();
       ++ibCount;
       result->link->TValue = result->TValue;
-      if ( PersistentDistributions )
+      if ( PersistentDistributions ){
 	result->link->TDistribution = result->TDistribution->to_VD_Copy();
+      }
       else {
 	result->link->TDistribution = result->TDistribution;
 	result->TDistribution = NULL;
@@ -540,8 +564,9 @@ namespace Timbl {
 						vector<Feature*>& Feats,
 						Target *Targ,
 						int level ){
-    if ( !is )
+    if ( !is ){
       return NULL;
+    }
     IBtree *result = new IBtree();
     ++ibCount;
     char delim;
@@ -587,8 +612,9 @@ namespace Timbl {
       result->link = new IBtree();
       ++ibCount;
       result->link->TValue = result->TValue;
-      if ( PersistentDistributions )
+      if ( PersistentDistributions ){
 	result->link->TDistribution = result->TDistribution->to_VD_Copy();
+      }
       else {
 	result->link->TDistribution = result->TDistribution;
 	result->TDistribution = NULL;
@@ -615,8 +641,9 @@ namespace Timbl {
       // but we need to cleanup behind us also
       return true;
     }
-    else
+    else {
       return false;
+    }
   }
 
   void InstanceBase_base::fill_index(){
@@ -639,8 +666,9 @@ namespace Timbl {
       }
       return true;
     }
-    else
+    else {
       return false;
+    }
   }
 
   bool InstanceBase_base::read_IB( istream &is,
@@ -673,16 +701,18 @@ namespace Timbl {
 	  Warning( what );
 	}
       }
-      if ( !TopDistribution )
+      if ( !TopDistribution ){
 	Error( "problems reading Top Distribution from Instance Base file" );
+      }
       else {
 	if ( look_ahead( is ) == '[' ){
 	  InstBase = read_list( is, Feats, Targs, 0 );
 	}
 	if ( InstBase ){
 	  is >> ws >> buf;
-	  if ( buf.empty() || buf[0] != ')' )
+	  if ( buf.empty() || buf[0] != ')' ){
 	    Error( "missing last `)` in Instance base file, found " + buf );
+	  }
 	}
       }
     }
@@ -703,11 +733,13 @@ namespace Timbl {
     vector<string> vals;
     while ( getline( is, line ) ){
       size_t i = TiCC::split( line, vals );
-      if ( i == 2 )
+      if ( i == 2 ){
 	// just ignore index!
 	cats->Hash( vals[1] );
-      else
+      }
+      else {
 	break;
+      }
       is >> ws;
     }
     if ( !compare_nocase( line, "Features" ) ){
@@ -716,11 +748,13 @@ namespace Timbl {
     }
     while ( getline( is, line ) ){
       size_t i = TiCC::split( line, vals );
-      if ( i == 2 )
+      if ( i == 2 ){
 	// just ignore index!
 	feats->Hash( vals[1] );
-      else
+      }
+      else {
 	break;
+      }
     }
     return true;
   }
@@ -738,8 +772,9 @@ namespace Timbl {
       // but we need to cleanup behind us also
       return true;
     }
-    else
+    else {
       return false;
+    }
   }
 
   bool IG_InstanceBase::ReadIB( istream &is,
@@ -755,8 +790,9 @@ namespace Timbl {
       }
       return true;
     }
-    else
+    else {
       return false;
+    }
   }
 
   bool InstanceBase_base::read_IB( istream &is,
@@ -791,8 +827,9 @@ namespace Timbl {
 	catch ( const string& what ){
 	  Warning( what );
 	}
-	if ( !TopDistribution )
+	if ( !TopDistribution ){
 	  Error( "problems reading Top Distribution from Instance Base file" );
+	}
       }
       else {
 	Error( "problems reading Top Distribution from Instance Base file" );
@@ -802,19 +839,22 @@ namespace Timbl {
       }
       if ( InstBase ){
 	is >> delim;
-	if ( delim != ')' )
+	if ( delim != ')' ){
 	  Error( string("missing last `)` in Instance base file, found: ")
 		 + delim );
+	}
       }
     }
     return (InstBase != NULL);
   }
 
   bool InstanceBase_base::HasDistributions() const {
-    if ( InstBase && InstBase->link )
+    if ( InstBase && InstBase->link ){
       return InstBase->link->TDistribution != NULL;
-    else
+    }
+    else {
       return false;
+    }
   }
 
   inline ValueDistribution *IBtree::sum_distributions( bool keep ){
@@ -822,19 +862,23 @@ namespace Timbl {
     // distibutions of all branches.
     ValueDistribution *result;
     if ( !keep ){
-      if ( TDistribution )
+      if ( TDistribution ){
 	if ( FValue ){
 	  result = TDistribution;
 	  TDistribution = NULL;
 	}
-	else
+	else {
 	  result = TDistribution->to_VD_Copy();
-      else
+	}
+      }
+      else {
 	result = new ValueDistribution();
+      }
       IBtree *pnt = this->next;
       while ( pnt ){
-	if ( pnt->TDistribution )
+	if ( pnt->TDistribution ){
 	  result->Merge( *(pnt->TDistribution) );
+	}
 	if ( FValue ){
 	  delete pnt->TDistribution;
 	  pnt->TDistribution = NULL;
@@ -843,10 +887,12 @@ namespace Timbl {
       }
     }
     else {
-      if ( TDistribution )
+      if ( TDistribution ){
 	result = TDistribution->to_VD_Copy();
-      else
+      }
+      else {
 	result = new ValueDistribution();
+      }
       IBtree *pnt = this->next;
       while ( pnt ){
 	if ( pnt->TDistribution ){
@@ -905,8 +951,9 @@ namespace Timbl {
 	pnt->link->redo_distributions();
 	delete pnt->TDistribution;
 	pnt->TDistribution = pnt->link->sum_distributions( false );
-	if ( pnt->FValue->ValFreq() > 0 )
+	if ( pnt->FValue->ValFreq() > 0 ){
 	  pnt->FValue->ReconstructDistribution( *(pnt->TDistribution) );
+	}
       }
       pnt = pnt->next;
     }
@@ -927,8 +974,9 @@ namespace Timbl {
 	--cnt;
 	delete dead;
       }
-      else
+      else {
 	tmp = &((*tmp)->next);
+      }
     }
     return result;
   }
@@ -940,14 +988,17 @@ namespace Timbl {
     // leaves of the Tree and moving back to the top.
     IBtree *pnt = this;
     while ( pnt ){
-      if ( pnt->link != NULL )
+      if ( pnt->link != NULL ){
 	pnt->link = pnt->link->Reduce( pnt->TValue, cnt, depth-1 );
+      }
       pnt = pnt->next;
     }
-    if ( depth <= 0 )
+    if ( depth <= 0 ){
       return make_unique( Top, cnt );
-    else
+    }
+    else {
       return this;
+    }
   }
 
   const ValueDistribution *IBtree::exact_match( const Instance& Inst ) const {
@@ -957,23 +1008,28 @@ namespace Timbl {
     int pos = 0;
     while ( pnt ){
       if ( pnt->link == NULL ){
-	if ( pnt->TDistribution->ZeroDist() )
+	if ( pnt->TDistribution->ZeroDist() ){
 	  return NULL;
-	else
+	}
+	else {
 	  return pnt->TDistribution;
+	}
       }
-      else if ( Inst.FV[pos]->isUnknown() )
+      else if ( Inst.FV[pos]->isUnknown() ){
 	return NULL;
+      }
       else if ( pnt->FValue == Inst.FV[pos] ){
-	if ( pnt->FValue->ValFreq() == 0 )
+	if ( pnt->FValue->ValFreq() == 0 ){
 	  return NULL;
+	}
 	else {
 	  pnt = pnt->link;
 	  pos++;
 	}
       }
-      else
+      else {
 	pnt = pnt->next;
+      }
     }
     return NULL;
   }
@@ -1180,8 +1236,9 @@ namespace Timbl {
 
   void InstanceBase_base::CleanPartition( bool distToo ){
     InstBase = 0; // prevent deletion of InstBase in next step!
-    if ( !distToo )
+    if ( !distToo ){
       TopDistribution = 0; // save TopDistribution for deletion
+    }
     delete this;
   }
 
@@ -1233,8 +1290,9 @@ namespace Timbl {
     // is build incremental
     ValueDistribution dist;
     while ( pnt ){
-      if ( pnt->TDistribution )
+      if ( pnt->TDistribution ){
 	dist.Merge( *pnt->TDistribution );
+      }
       pnt = pnt->next;
     }
     bool dummy;
@@ -1263,22 +1321,25 @@ namespace Timbl {
     else {
       for ( unsigned int i = 0; i < Depth; ++i ){
 #ifdef IBSTATS
-	hlp = (*pnt)->add_feat_val( Inst.FV[i], mismatch[i], pnt, ibCount );
+	hlp = IBtree::add_feat_val( Inst.FV[i], mismatch[i], pnt, ibCount );
 #else
-	hlp = (*pnt)->add_feat_val( Inst.FV[i], pnt, ibCount );
+	hlp = IBtree::add_feat_val( Inst.FV[i], pnt, ibCount );
 #endif
-	if ( i==0 && hlp->next == 0 )
+	if ( i==0 && hlp->next == 0 ){
 	  LastInstBasePos = hlp;
+	}
 	pnt = &(hlp->link);
       }
     }
     if ( *pnt == NULL ){
       *pnt = new IBtree();
       ++ibCount;
-      if ( abs( Inst.ExemplarWeight() ) > Epsilon )
+      if ( abs( Inst.ExemplarWeight() ) > Epsilon ){
 	(*pnt)->TDistribution = new WValueDistribution();
-      else
+      }
+      else {
 	(*pnt)->TDistribution = new ValueDistribution;
+      }
       NumOfTails++;
     }
     int occ = Inst.Occurrences();
@@ -1321,8 +1382,9 @@ namespace Timbl {
     TopDistribution->Merge( *ib->TopDistribution );
 #ifdef IBSTATS
     if ( ib->mismatch.size() > 0 ){
-      if ( mismatch.size() == 0 )
+      if ( mismatch.size() == 0 ){
 	mismatch.resize( ib->mismatch.size(), 0 );
+      }
       for ( unsigned int i = 0; i < mismatch.size(); ++i ){
 	mismatch[i] += ib->mismatch[i];
       }
@@ -1339,8 +1401,9 @@ namespace Timbl {
     while ( pnt ){
       delete pnt->TDistribution;
       pnt->TDistribution = 0;
-      if ( pnt->link )
+      if ( pnt->link ){
 	pnt->link->cleanDistributions();
+      }
       pnt = pnt->next;
     }
   }
@@ -1374,10 +1437,12 @@ namespace Timbl {
 	    --ib->ibCount;
 	    delete ibPnt;
 	    while ( snip ){
-	      if ( PersistentDistributions )
+	      if ( PersistentDistributions ){
 		(*pnt)->TDistribution->Merge( *snip->TDistribution );
-	      else
+	      }
+	      else {
 		delete snip->TDistribution;
+	      }
 	      IBtree **tmp = &(*pnt)->link;
 	      while ( *tmp && (*tmp)->FValue->Index() < snip->FValue->Index() ){
 		tmp = &(*tmp)->next;
@@ -1385,7 +1450,7 @@ namespace Timbl {
 	      IBtree *nxt = snip->next;
 	      snip->next = 0;
 	      if ( *tmp ){
-		if( (*tmp)->FValue->Index() == snip->FValue->Index() ){
+		if ( (*tmp)->FValue->Index() == snip->FValue->Index() ){
 		  return false;
 		}
 		snip->next = *tmp;
@@ -1406,8 +1471,9 @@ namespace Timbl {
     TopDistribution->Merge( *ib->TopDistribution );
 #ifdef IBSTATS
     if ( ib->mismatch.size() > 0 ){
-      if ( mismatch.size() == 0 )
+      if ( mismatch.size() == 0 ){
 	mismatch.resize( ib->mismatch.size(), 0 );
+      }
       for ( unsigned int i = 0; i < mismatch.size(); ++i ){
 	mismatch[i] += ib->mismatch[i];
       }
@@ -1436,8 +1502,9 @@ namespace Timbl {
 	    pnt = pnt->link;
 	    pos++;
 	  }
-	  else
+	  else {
 	    pnt = pnt->next;
+	  }
 	}
       }
     }
@@ -1455,12 +1522,14 @@ namespace Timbl {
   const IBtree *IBtree::search_node( FeatureValue *fv ) const {
     const IBtree *pnt = 0;
     if ( fv ){
-      if ( fv->isUnknown() )
+      if ( fv->isUnknown() ){
 	return 0;
+      }
       pnt = this;
       while ( pnt ){
-	if ( pnt->FValue == fv )
+	if ( pnt->FValue == fv ){
 	  break;
+	}
 	pnt = pnt->next;
       }
     }
@@ -1469,14 +1538,17 @@ namespace Timbl {
 
   const IBtree *InstanceBase_base::fast_search_node( FeatureValue *fv ) {
     const IBtree *result = 0;
-    if ( fast_index.empty() )
+    if ( fast_index.empty() ){
       fill_index();
+    }
     if ( fv ){
-      if ( fv->isUnknown() )
+      if ( fv->isUnknown() ){
 	return 0;
+      }
       FI_map::const_iterator It = fast_index.find( fv->Index() );
-      if ( It != fast_index.end() )
+      if ( It != fast_index.end() ){
 	result = It->second;
+      }
     }
     return result;
   }
@@ -1503,13 +1575,16 @@ namespace Timbl {
       }
       InstPath[i] = pnt;
       RestartSearch[i] = pnt;
-      if ( i == 0 )
+      if ( i == 0 ){
 	pnt = fast_search_node( (*testInst)[offSet+i] );
-      else
+      }
+      else {
 	pnt = pnt->search_node( (*testInst)[offSet+i] );
+      }
       if ( pnt ){ // found an exact match, so mark restart position
-	if ( RestartSearch[i] == pnt )
+	if ( RestartSearch[i] == pnt ){
 	  RestartSearch[i] = pnt->next;
+	}
 	SkipSearch[i] = pnt;
 	InstPath[i] = pnt;
       }
@@ -1568,8 +1643,9 @@ namespace Timbl {
 	pnt = pnt->next;
       }
       if ( !pnt ) {
-	if ( pos == 0 )
+	if ( pos == 0 ){
 	  goon = false;
+	}
 	else {
 	  pos--;
 	  //	  cerr << "decremented pos to " << pos << endl;
@@ -1586,10 +1662,12 @@ namespace Timbl {
       for (  size_t j=pos+1; j < Depth; ++j ){
 	const IBtree *tmp = pnt->search_node( (*testInst)[offSet+j] );
 	if ( tmp ){ // we found an exact match, so mark Restart position
-	  if ( pnt == tmp )
+	  if ( pnt == tmp ){
 	    RestartSearch[j] = pnt->next;
-	  else
+	  }
+	  else {
 	    RestartSearch[j] = pnt;
+	  }
 	  SkipSearch[j] = tmp;
 	  InstPath[j] = tmp;
 	  Path[j] = tmp->FValue;
@@ -1606,8 +1684,9 @@ namespace Timbl {
 	cerr << "set Path[" << j<< "] to " << Path[j] << endl;
 #endif
       }
-      if ( pnt )
+      if ( pnt ){
 	result = pnt->TDistribution;
+      }
     }
     if ( result && result->ZeroDist() ){
       // This might happen when doing LOO or CV tests
@@ -1645,20 +1724,24 @@ namespace Timbl {
     const IBtree *pnt = fast_search_node( Inst.FV[pos] );
     while ( pnt ){
       result = pnt->TValue;
-      if ( PersistentDistributions )
+      if ( PersistentDistributions ){
 	Dist = pnt->TDistribution;
+      }
       pnt = pnt->link;
-      if ( pnt && !pnt->FValue )
+      if ( pnt && !pnt->FValue ){
 	pnt = NULL;
+      }
       leaf = (pnt == NULL);
       ++pos;
-      if ( pnt )
+      if ( pnt ){
 	pnt = pnt->search_node( Inst.FV[pos] );
+      }
     }
     end_level = pos;
     if ( end_level == 0 ){
-      if ( !WTop && TopDistribution )
+      if ( !WTop && TopDistribution ){
 	WTop = TopDistribution->to_WVD_Copy();
+      }
       Dist = WTop;
     }
     return Dist;
@@ -1706,8 +1789,9 @@ namespace Timbl {
 	}
 	pos++;
       }
-      else
+      else {
 	pnt = pnt->next;
+      }
     }
     if ( pos == threshold ){
       if ( pnt ){
@@ -1720,8 +1804,9 @@ namespace Timbl {
     }
     else {
       if ( pos == 0 && dist == NULL ){
-	if ( !WTop && TopDistribution )
+	if ( !WTop && TopDistribution ){
 	  WTop = TopDistribution->to_WVD_Copy();
+	}
 	dist = WTop;
 	bool dummy;
 	TV = TopTarget( dummy );
@@ -1758,8 +1843,9 @@ namespace Timbl {
 	  break;
 	}
       }
-      else
+      else {
 	pnt = pnt->next;
+      }
     }
     if ( last_match ){
       subtree = IBPartition( last_match );
