@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   ILK   - Tilburg University
   CLST  - Radboud University
   CLiPS - University of Antwerp
@@ -58,12 +58,14 @@ namespace Timbl {
 	stats.clear();
 	delete confusionInfo;
 	confusionInfo = 0;
-	if ( Verbosity(ADVANCED_STATS) )
+	if ( Verbosity(ADVANCED_STATS) ){
 	  confusionInfo = new ConfusionMatrix( Targets->ValuesArray.size() );
+	}
 	if ( !is_copy ){
 	  InitWeights();
-	  if ( do_diversify )
+	  if ( do_diversify ){
 	    diverseWeights();
+	  }
 	  srand( random_seed );
 	}
 	MBL_init = true;
@@ -72,10 +74,12 @@ namespace Timbl {
   }
 
   bool IG_Experiment::checkTestFile(){
-    if ( TimblExperiment::checkTestFile() )
+    if ( TimblExperiment::checkTestFile() ){
       return sanityCheck();
-    else
+    }
+    else {
       return false;
+    }
   }
 
   ostream& operator<< ( ostream& os,
@@ -118,8 +122,9 @@ namespace Timbl {
       TiCC::Timer learnT;
       learnT.start();
       InitInstanceBase();
-      if ( ExpInvalid() )
+      if ( ExpInvalid() ){
 	return false;
+      }
       if ( EffectiveFeatures() < 2 ){
 	fileIndex fmIndex;
 	result = build_file_index( CurrentDataFile, fmIndex );
@@ -147,8 +152,9 @@ namespace Timbl {
 	      chopLine( Buffer );
 	      // Progress update.
 	      //
-	      if (( stats.dataLines() % Progress() ) == 0)
+	      if ( ( stats.dataLines() % Progress() ) == 0 ){
 		time_stamp( "Learning:  ", stats.dataLines() );
+	      }
 	      chopped_to_instance( TrainWords );
 	      if ( !outInstanceBase ){
 		outInstanceBase = new IG_InstanceBase( EffectiveFeatures(),
@@ -157,7 +163,6 @@ namespace Timbl {
 						       false,
 						       true );
 	      }
-	      //		cerr << "add instance " << &CurrInst << endl;
 	      outInstanceBase->AddInstance( CurrInst );
 	      ++sit;
 	    }
@@ -225,8 +230,9 @@ namespace Timbl {
 		  chopLine( Buffer );
 		  // Progress update.
 		  //
-		  if (( stats.dataLines() % Progress() ) == 0)
+		  if ( ( stats.dataLines() % Progress() ) == 0 ){
 		    time_stamp( "Learning:  ", stats.dataLines() );
+		  }
 		  chopped_to_instance( TrainWords );
 		  if ( !PartInstanceBase ){
 		    PartInstanceBase = new IG_InstanceBase( EffectiveFeatures(),
@@ -284,15 +290,17 @@ namespace Timbl {
 		  chopLine( Buffer );
 		  // Progress update.
 		  //
-		  if (( stats.dataLines() % Progress() ) == 0)
+		  if ( ( stats.dataLines() % Progress() ) == 0 ){
 		    time_stamp( "Learning:  ", stats.dataLines() );
+		  }
 		  chopped_to_instance( TrainWords );
-		  if ( !outInstanceBase )
+		  if ( !outInstanceBase ){
 		    outInstanceBase = new IG_InstanceBase( EffectiveFeatures(),
 							   ibCount,
 							   (RandomSeed()>=0),
 							   false,
 							   true );
+		  }
 		  //	      cerr << "add instance " << &CurrInst << endl;
 		  outInstanceBase->AddInstance( CurrInst );
 		  ++sit;
@@ -337,10 +345,12 @@ namespace Timbl {
 
 
   bool IG_Experiment::checkLine( const string& line ){
-    if ( TimblExperiment::checkLine( line ) )
+    if ( TimblExperiment::checkLine( line ) ){
       return sanityCheck();
-    else
+    }
+    else {
       return false;
+    }
   }
 
   bool IG_Experiment::sanityCheck() const {
@@ -387,28 +397,34 @@ namespace Timbl {
     Distance = sum_remaining_weights( match_depth );
     if ( ResultDist &&
 	 InstanceBase && InstanceBase->PersistentD() ){
-      if ( match_depth == 0 )
-	bestResult.addTop( ResultDist );
-      else
-	bestResult.addConstant( ResultDist );
+      if ( match_depth == 0 ) {
+	bestResult.addTop( ResultDist, TV );
+      }
+      else {
+	bestResult.addConstant( ResultDist, TV );
+      }
     }
-    if ( confusionInfo )
+    if ( confusionInfo ){
       confusionInfo->Increment( Inst.TV, TV );
+    }
     bool correct = Inst.TV && ( TV == Inst.TV );
     if ( correct ){
       stats.addCorrect();
-      if ( Tie )
+      if ( Tie ){
 	stats.addTieCorrect();
+      }
     }
-    else if ( Tie )
+    else if ( Tie ){
       stats.addTieFailure();
+    }
     return TV;
   }
 
   void IG_Experiment::showTestingInfo( ostream& os ){
-    if ( !Verbosity(SILENT)) {
-      if ( Verbosity(OPTIONS) )
+    if ( !Verbosity(SILENT) ) {
+      if ( Verbosity(OPTIONS) ){
 	ShowSettings( os );
+      }
       os << endl << "Starting to test, Testfile: " << testStreamName << endl
 	 << "Writing output in:          " << outStreamName << endl
 	 << "Algorithm     : IGTree" << endl;
@@ -427,8 +443,9 @@ namespace Timbl {
 	Warning( "can't open outputfile: " + FileName );
       }
       else {
-	if ( !Verbosity(SILENT) )
+	if ( !Verbosity(SILENT) ){
 	  Info( "Writing Instance-Base in: " + FileName );
+	}
 	if ( PutInstanceBase( outfile ) ){
 	  string tmp = FileName;
 	  tmp += ".wgt";
@@ -477,25 +494,30 @@ namespace Timbl {
 	int pos=0;
 	for ( size_t i=0; i < NumOfFeatures(); ++i ){
 	  Features[i]->SetWeight( 1.0 );
-	  if ( Features[permutation[i]]->Ignore() )
+	  if ( Features[permutation[i]]->Ignore() ){
 	    PermFeatures[i] = NULL;
-	  else
+	  }
+	  else {
 	    PermFeatures[pos++] = Features[permutation[i]];
+	  }
 	}
-	if ( Hashed )
+	if ( Hashed ){
 	  result = InstanceBase->ReadIB( is, PermFeatures,
 					 Targets,
 					 TargetStrings, FeatureStrings,
 					 Version );
-	else
+	}
+	else {
 	  result = InstanceBase->ReadIB( is, PermFeatures,
 					 Targets,
 					 Version );
+	}
 	if ( result ){
 	  if ( !InstanceBase->HasDistributions() ){
-	    if ( KeepDistributions() )
+	    if ( KeepDistributions() ){
 	      Error( "Instance base doesn't contain Distributions, "
 		     "+D option impossible" );
+	    }
 	    else if ( Verbosity(DISTRIB) ){
 	      Info( "Instance base doesn't contain Distributions, "
 		    "+vDB option disabled ...."  );
@@ -516,8 +538,9 @@ namespace Timbl {
 	Error( "can't open: " + FileName );
       }
       else {
-	if ( !Verbosity(SILENT) )
+	if ( !Verbosity(SILENT) ){
 	  Info( "Reading Instance-Base from: " + FileName );
+	}
 	if ( GetInstanceBase( infile ) ){
 	  if ( !Verbosity(SILENT) ){
 	    writePermutation( cout );
