@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   ILK   - Tilburg University
   CLST  - Radboud University
   CLiPS - University of Antwerp
@@ -65,8 +65,9 @@ namespace Timbl {
 
   inline int random_number( int Min, int Max ){
     // calculate a random integer within the interval [min,max]
-    if ( Min == Max )
+    if ( Min == Max ){
       return Min;
+    }
     double randnum = (double)rand()/(double)RAND_MAX;
     randnum *= (Max-Min);
     randnum += Min;
@@ -84,8 +85,9 @@ namespace Timbl {
   double ValueDistribution::Confidence( const TargetValue *tv ) const {
     VDlist::const_iterator it = distribution.begin();
     while ( it != distribution.end() ){
-      if ( it->second->Value() == tv )
+      if ( it->second->Value() == tv ){
 	return it->second->Weight();
+      }
       ++it;
     }
     return 0.0;
@@ -100,8 +102,9 @@ namespace Timbl {
     while ( it != distribution.end() ){
       Vfield *f = it->second;
       if ( f->frequency >= minf ){
-	if ( !first )
+	if ( !first ){
 	  oss << ", ";
+	}
 	oss << f->value << " " << double(f->frequency);
 	first = false;
       }
@@ -127,8 +130,9 @@ namespace Timbl {
 	++it;
 	continue;
       }
-      if ( !first )
+      if ( !first ){
 	oss << ", ";
+      }
       oss << f->value << " " << f->weight;
       first = false;
       ++it;
@@ -158,11 +162,13 @@ namespace Timbl {
       std::set<double, dblCmp>::iterator rit = freqs.begin();
       while ( rit != freqs.end() && cnt < beam ) {
 	++cnt;
-	if ( cnt < beam )
+	if ( cnt < beam ){
 	  ++rit;
+	}
       }
-      if ( cnt == beam )
+      if ( cnt == beam ){
 	minw = *rit;
+      }
     }
     DistToString( DistStr, minw );
   }
@@ -182,11 +188,13 @@ namespace Timbl {
       std::set<double, dblCmp>::iterator rit = wgths.begin();
       while ( rit != wgths.end() && cnt < beam ) {
 	++cnt;
-	if ( cnt < beam )
+	if ( cnt < beam ){
 	  ++rit;
+	}
       }
-      if ( cnt == beam )
+      if ( cnt == beam ){
 	minw = *rit;
+      }
     }
     DistToString( DistStr, minw );
   }
@@ -311,11 +319,12 @@ namespace Timbl {
     ostringstream oss;
     oss << "{ ";
     bool first = true;
-    for( const auto& it : distribution ){
+    for ( const auto& it : distribution ){
       Vfield *f = it.second;
       if ( f->frequency > 0 ){
-	if ( !first )
+	if ( !first ){
 	  oss << ", ";
+	}
 	oss << f->value->Index() << " " << f->frequency;
 	first = false;
       }
@@ -328,11 +337,12 @@ namespace Timbl {
     ostringstream oss;
     bool first = true;
     oss << "{ ";
-    for( const auto& it : distribution ){
+    for ( const auto& it : distribution ){
       Vfield *f = it.second;
       if ( f->frequency > 0 ){
-	if ( !first )
+	if ( !first ){
 	  oss << ", ";
+	}
 	oss << f->Value()->Index() << " "
 	    << f->frequency << " " << f->weight;
 	first = false;
@@ -350,11 +360,12 @@ namespace Timbl {
     ostringstream oss;
     oss << "{ ";
     bool first = true;
-    for( const auto& it : distribution ){
+    for ( const auto& it : distribution ){
       Vfield *f = it.second;
       if ( f->frequency > 0 ){
-	if ( !first )
+	if ( !first ){
 	  oss << ", ";
+	}
 	oss << f->value << " " << f->frequency;
 	first = false;
       }
@@ -367,11 +378,12 @@ namespace Timbl {
     ostringstream oss;
     oss << "{ ";
     bool first = true;
-    for( const auto& it : distribution ){
+    for ( const auto& it : distribution ){
       Vfield *f = it.second;
       if ( f->frequency > 0 ){
-	if ( !first )
+	if ( !first ){
 	  oss << ", ";
+	}
 	oss.setf(ios::showpoint);
 	oss << f->value << " " << f->frequency << " " << f->weight;
 	first = false;
@@ -408,8 +420,9 @@ namespace Timbl {
     if ( it != distribution.end() ){
       it->second->IncFreq( occ );
     }
-    else
+    else {
       distribution[id] = new Vfield( val, occ, 1.0 );
+    }
     total_items += occ;
     return true;
   }
@@ -449,11 +462,12 @@ namespace Timbl {
       if ( distribution.find(key) != distribution.end() ){
 	distribution[key]->AddFreq( vd->Freq() );
       }
-      else
+      else {
 	// VD might be weighted. But we don't need/want that info here
 	// Weight == Freq is more convenient
 	distribution[key] = new Vfield( vd->Value(), vd->Freq(),
 					vd->Freq() );
+      }
     }
     total_items += VD.total_items;
   }
@@ -495,9 +509,11 @@ namespace Timbl {
 	    Max = pnt->Freq();
 	    nof_best = 1;
 	  }
-	  else
-	    if ( pnt->Freq() == Max )
+	  else {
+	    if ( pnt->Freq() == Max ){
 	      nof_best++;
+	    }
+	  }
 	  ++It;
 	}
 	tie = ( nof_best > 1 );
@@ -506,10 +522,11 @@ namespace Timbl {
 	nof_best = 0;
 	while ( It != distribution.end() ){
 	  pnt = It->second;
-	  if ( pnt->Freq() == Max )
+	  if ( pnt->Freq() == Max ){
 	    if ( ++nof_best == pick ){
 	      return pnt->Value();
 	    }
+	  }
 	  ++It;
 	}
 	return NULL;
@@ -524,13 +541,14 @@ namespace Timbl {
 	    best = pnt->Value();
 	    Max = pnt->Freq();
 	  }
-	  else
+	  else {
 	    if ( pnt->Freq() == Max ) {
 	      tie = true;
 	      if ( pnt->Value()->ValFreq() > best->ValFreq() ){
 		best = pnt->Value();
 	      }
 	    }
+	  }
 	  ++It;
 	}
 	return best;
@@ -558,9 +576,11 @@ namespace Timbl {
 	    Max = It->second->Weight();
 	    nof_best = 1;
 	  }
-	  else
-	    if ( abs(It->second->Weight()- Max) < Epsilon )
+	  else {
+	    if ( abs(It->second->Weight()- Max) < Epsilon ){
 	      nof_best++;
+	    }
+	  }
 	  ++It;
 	}
 	tie = ( nof_best > 1 );
@@ -568,10 +588,11 @@ namespace Timbl {
 	It = distribution.begin();
 	nof_best = 0;
 	while ( It != distribution.end() ){
-	  if ( abs(It->second->Weight() - Max) < Epsilon )
+	  if ( abs(It->second->Weight() - Max) < Epsilon ){
 	    if ( ++nof_best == pick ){
 	      return It->second->Value();
 	    }
+	  }
 	  ++It;
 	}
 	return NULL;
@@ -585,13 +606,14 @@ namespace Timbl {
 	    best = It->second->Value();
 	    Max = It->second->Weight();
 	  }
-	  else
+	  else {
 	    if ( abs(It->second->Weight() - Max) < Epsilon ) {
 	      tie = true;
 	      if ( It->second->Value()->ValFreq() > best->ValFreq() ){
 		best = It->second->Value();
 	      }
 	    }
+	  }
 	  ++It;
 	}
 	return best;
@@ -685,8 +707,9 @@ namespace Timbl {
   struct D_D {
     D_D(): dist(0), value(0.0) {};
     explicit D_D( FeatureValue *fv ): value(0.0) {
-      if ( !TiCC::stringTo<double>( fv->Name(), value ) )
+      if ( !TiCC::stringTo<double>( fv->Name(), value ) ){
 	throw( logic_error("called DD with an non-numeric value" ) );
+      }
       dist = &fv->TargetDist;
     }
     ValueDistribution *dist;
@@ -717,16 +740,18 @@ namespace Timbl {
     size_t dd_len = ddv.size();
     int num_per_bin = (int)floor( (double)dd_len / BinSize);
     size_t rest = dd_len - num_per_bin * BinSize;
-    if ( rest )
+    if ( rest ){
       num_per_bin++;
+    }
     int jj = 0;
     int cnt = 0;
     for ( size_t m = 0; m < dd_len; ++m ){
       FVBin[jj]->TargetDist.Merge( *ddv[m]->dist );
       if ( ++cnt >= num_per_bin ){
 	++jj;
-	if ( --rest == 0 )
+	if ( --rest == 0 ){
 	  --num_per_bin;
+	}
 	cnt = 0;
       }
     }
@@ -773,8 +798,9 @@ namespace Timbl {
       info_gain  = 0.0;
       entropy = DBentropy;
     }
-    else
+    else {
       gain_ratio = info_gain / split_info;
+    }
   }
 
   void Feature::Statistics( double DBentropy, Target *Targets, bool full ){
@@ -797,13 +823,14 @@ namespace Timbl {
     if ( full ){
       ChiSquareStatistics( FVBin, BinSize, Targets );
       int cnt = 0;   // count effective values in Bin
-      for( int i=0; i < BinSize; ++i ){
-	if ( FVBin[i]->ValFreq() > 0 )
-	  cnt++;
+      for ( int i=0; i < BinSize; ++i ){
+	if ( FVBin[i]->ValFreq() > 0 ){
+	  ++cnt;
+	}
       }
       SharedVarianceStatistics( Targets, cnt );
     }
-    for( int i=0; i < BinSize; ++i ){
+    for ( int i=0; i < BinSize; ++i ){
       delete FVBin[i];
     }
   }
@@ -835,8 +862,9 @@ namespace Timbl {
     // Info. gain.
     //
     info_gain = DBentropy - entropy;
-    if ( info_gain < 0.0 )
+    if ( info_gain < 0.0 ){
       info_gain = 0.0;
+    }
     // And the split. info.
     //
     split_info = 0.0;
@@ -852,10 +880,12 @@ namespace Timbl {
     split_info = -split_info;
     // Gain ratio.
     //
-    if ( fabs(split_info) < Epsilon )
+    if ( fabs(split_info) < Epsilon ){
       gain_ratio = 0.0;
-    else
+    }
+    else {
       gain_ratio = info_gain / split_info;
+    }
   }
 
   void Feature::ChiSquareStatistics( vector<FeatureValue *>& FVA,
@@ -917,8 +947,9 @@ namespace Timbl {
 	    }
 	    ++It;
 	  }
-	  else
+	  else {
 	    break;
+	  }
 	}
 	while ( n < Size ){
 	  double tmp = ((double)n_dot_j[n++] * (double)n_i_dot[m]) /
@@ -995,8 +1026,9 @@ namespace Timbl {
 	    }
 	    ++It;
 	  }
-	  else
+	  else {
 	    break;
+	  }
 	}
 	while ( n < Size ){
 	  double tmp = ((double)n_dot_j[n++] * (double)n_i_dot[m]) /
@@ -1014,7 +1046,7 @@ namespace Timbl {
     double result = 0.0;
     if ( F != G ){
       bool dummy;
-      if ( metric->isStorable() && matrixPresent( dummy )&&
+      if ( metric->isStorable() && matrixPresent( dummy ) &&
 	   F->ValFreq() >= matrix_clip_freq &&
 	   G->ValFreq() >= matrix_clip_freq ){
 	result = metric_matrix->Extract( F, G );
@@ -1038,8 +1070,9 @@ namespace Timbl {
 
   ostream& operator<<(ostream& os, const ValueDistribution *vd ) {
     string tmp = "{null}";
-    if( vd )
+    if ( vd ){
       vd->DistToString( tmp );
+    }
     os << tmp;
     return os;
   }
@@ -1086,13 +1119,15 @@ namespace Timbl {
 	  next = look_ahead(is);
 	}
 	else if ( next == '}' ){
-	  if ( !result )
+	  if ( !result ){
 	    result = new ValueDistribution();
+	  }
 	  result->SetFreq( target, freq );
 	}
 	else if ( isdigit(next) ){
-	  if ( !result )
+	  if ( !result ){
 	    result = new WValueDistribution();
+	  }
 	  double sw;
 	  is >> sw;
 	  result->SetFreq( target, freq, sw );
@@ -1103,8 +1138,9 @@ namespace Timbl {
 	  }
 	}
       } while ( is && next != '}' );
-      if ( is )
+      if ( is ){
 	is >> nextCh;   // skip }
+      }
       else {
 	delete result;
 	throw string( "missing '}' " );
@@ -1139,8 +1175,9 @@ namespace Timbl {
 	if ( do_fr ){
 	  target = Targ->add_value( index, freq );
 	}
-	else
+	else {
 	  target = Targ->ReverseLookup( index );
+	}
 	if ( !target ){
 	  delete result;
 	  result = 0;
@@ -1148,22 +1185,25 @@ namespace Timbl {
 	}
 	next = look_ahead(is);
 	if ( next == ',' ){
-	  if ( !result )
+	  if ( !result ){
 	    result = new ValueDistribution();
+	  }
 	  result->SetFreq( target, freq );
 	  is >> nextCh;
 	  next = look_ahead(is);
 	}
 	else if ( next == '}' ){
-	  if ( !result )
+	  if ( !result ){
 	    result = new ValueDistribution();
+	  }
 	  result->SetFreq( target, freq );
 	}
 	else if ( isdigit(next) ){
 	  double sw;
 	  is >> sw;
-	  if ( !result )
+	  if ( !result ){
 	    result = new WValueDistribution();
+	  }
 	  result->SetFreq( target, freq, sw );
 	  next = look_ahead(is);
 	  if ( next == ',' ){
@@ -1172,8 +1212,9 @@ namespace Timbl {
 	  }
 	}
       } while ( is && next != '}' );
-      if ( is )
+      if ( is ){
 	is >> nextCh;   // skip }
+      }
       else {
 	delete result;
 	throw string( "missing '}' " );
@@ -1187,8 +1228,9 @@ namespace Timbl {
     if ( vc ){
       os << vc->Name();
     }
-    else
+    else {
       os << "*FV-NF*";
+    }
     return os;
   }
 
@@ -1215,8 +1257,9 @@ namespace Timbl {
     size_t result = 0;
     VCarrtype::const_iterator it = ValuesArray.begin();
     while( it != ValuesArray.end() ){
-      if ( (*it)->ValFreq() > 0 )
+      if ( (*it)->ValFreq() > 0 ){
 	++result;
+      }
       ++it;
     }
     return result;
@@ -1237,8 +1280,9 @@ namespace Timbl {
     unsigned int index = TokenTree->Lookup( str );
     if ( index ) {
       IVCmaptype::const_iterator it = ValuesMap.find( index );
-      if ( it != ValuesMap.end() )
-	result =  reinterpret_cast<FeatureValue*>(it->second);
+      if ( it != ValuesMap.end() ){
+	result = reinterpret_cast<FeatureValue*>(it->second);
+      }
     }
     return result;
   }
@@ -1254,7 +1298,7 @@ namespace Timbl {
 				    TargetValue *tv,
 				    int freq ){
     IVCmaptype::const_iterator it = ValuesMap.find( index );
-    if(  it == ValuesMap.end() ){
+    if (  it == ValuesMap.end() ){
       const string& value = TokenTree->ReverseLookup( index );
       // we want to store the singleton value for this index
       // so we MUST reverse lookup the index
@@ -1267,8 +1311,9 @@ namespace Timbl {
       it->second->IncValFreq( freq );
     }
     FeatureValue *result =  reinterpret_cast<FeatureValue*>(ValuesMap[index]);
-    if ( tv )
+    if ( tv ){
       result->TargetDist.IncFreq(tv, freq );
+    }
     return result;
   }
 
@@ -1277,8 +1322,9 @@ namespace Timbl {
     bool result = false;
     if ( FV ){
       FV->incr_val_freq();
-      if ( tv )
+      if ( tv ){
 	FV->TargetDist.IncFreq(tv,1);
+      }
       result = true;
     }
     return result;
@@ -1288,8 +1334,9 @@ namespace Timbl {
     bool result = false;
     if ( FV ){
       FV->decr_val_freq();
-      if ( tv )
+      if ( tv ){
 	FV->TargetDist.DecFreq(tv);
+      }
       result = true;
     }
     return result;
@@ -1313,17 +1360,21 @@ namespace Timbl {
   }
 
   bool Feature::isNumerical() const {
-    if ( metric && metric->isNumerical() )
+    if ( metric && metric->isNumerical() ){
       return true;
-    else
+    }
+    else {
       return false;
+    }
   }
 
   bool Feature::isStorableMetric() const {
-    if ( metric && metric->isStorable() )
+    if ( metric && metric->isStorable() ){
       return true;
-    else
+    }
+    else {
       return false;
+    }
   }
 
   BaseFeatTargClass::BaseFeatTargClass( Hash::StringHash *T ):
@@ -1380,8 +1431,9 @@ namespace Timbl {
   bool Feature::matrixPresent( bool& isRead ) const {
     isRead = false;
     if ( metric_matrix != 0 ){
-      if ( PrestoreStatus == ps_ok )
+      if ( PrestoreStatus == ps_ok ){
 	return true;
+      }
       else if ( PrestoreStatus == ps_read ){
 	isRead = true;
 	return true;
@@ -1391,10 +1443,12 @@ namespace Timbl {
   }
 
   size_t Feature::matrix_byte_size() const {
-    if ( metric_matrix )
+    if ( metric_matrix ){
       return metric_matrix->NumBytes();
-    else
+    }
+    else {
       return 0;
+    }
   }
 
   FeatVal_Stat Feature::prepare_numeric_stats(){
@@ -1416,17 +1470,21 @@ namespace Timbl {
 	  n_min = tmp;
 	  n_max = tmp;
 	}
-	else if ( tmp < n_min )
+	else if ( tmp < n_min ){
 	  n_min = tmp;
-	else if ( tmp > n_max )
+	}
+	else if ( tmp > n_max ){
 	  n_max = tmp;
+	}
       }
       ++it;
     }
-    if ( fabs(n_max - n_min) < Epsilon )
+    if ( fabs(n_max - n_min) < Epsilon ){
       return SingletonNumeric;
-    else
+    }
+    else {
       return NumericValue;
+    }
   }
 
   inline int min( int i1, int i2 ) { return (i1>i2?i2:i1); }
@@ -1436,10 +1494,12 @@ namespace Timbl {
     size_t NumInst = Targ->TotalValues();
     int NumCats = Targ->EffectiveValues();
     int k = min( NumCats, eff_cnt ) - 1;
-    if ( k == 0 || NumInst == 0 )
+    if ( k == 0 || NumInst == 0 ){
       shared_variance = 0;
-    else
+    }
+    else {
       shared_variance = chi_square / (double)( NumInst * k );
+    }
   }
 
   void Feature::StandardDeviationStatistics( ){
@@ -1460,10 +1520,12 @@ namespace Timbl {
   }
 
   void Feature::clear_matrix(){
-    if ( PrestoreStatus == ps_read )
+    if ( PrestoreStatus == ps_read ){
       return;
-    else
+    }
+    else {
       delete_matrix();
+    }
   }
 
   void Feature::delete_matrix(){
@@ -1492,10 +1554,12 @@ namespace Timbl {
     //
     // Store a complete distance matrix.
     //
-    if ( PrestoreStatus == ps_read )
+    if ( PrestoreStatus == ps_read ){
       return true;
-    if ( !metric_matrix )
+    }
+    if ( !metric_matrix ){
       metric_matrix = new SparseSymetricMatrix<ValueClass*>();
+    }
     if ( PrestoreStatus != ps_failed && metric->isStorable( ) ) {
       try {
 	for ( const auto& FV_i : ValuesArray ){
@@ -1539,13 +1603,15 @@ namespace Timbl {
 	  os << "\t" << it->second;
 	  ++it;
 	}
-	else
+	else {
 	  os << "\t" << 0.0;
+	}
       }
       os << setprecision( old_prec );
     }
-    else
+    else {
       os << "(Null SA)";
+    }
     return os;
   }
 
@@ -1642,13 +1708,17 @@ namespace Timbl {
   }
 
   bool Feature::fill_matrix( istream &is ) {
-    if ( !metric_matrix )
+    if ( !metric_matrix ){
       metric_matrix = new SparseSymetricMatrix<ValueClass*>();
-    else
+    }
+    else {
       metric_matrix->Clear();
+    }
     string line;
     while ( getline(is,line) ){
-      if ( line.empty() ) break;
+      if ( line.empty() ){
+	break;
+      }
       vector<string> arr;
       double d;
       if ( TiCC::split_at( line, arr, " " ) != 2 ){
@@ -1731,7 +1801,7 @@ namespace Timbl {
 
   TargetValue *Target::add_value( size_t index, int freq ){
     IVCmaptype::const_iterator it = ValuesMap.find( index );
-    if(  it == ValuesMap.end() ){
+    if (  it == ValuesMap.end() ){
       const string& name = TokenTree->ReverseLookup( index );
       // we want to store the singleton value for this index
       // so we MUST reverse lookup the index
@@ -1808,14 +1878,16 @@ namespace Timbl {
     if ( I ){
       os << *I;
     }
-    else
+    else {
       os << " Empty Instance";
+    }
     return os;
   }
 
   ostream& operator<<(ostream& os, const Instance& I ){
-    for ( unsigned int i=0; i < I.FV.size(); ++i )
+    for ( unsigned int i=0; i < I.FV.size(); ++i ){
       os << I.FV[i] << ", ";
+    }
     os << I.TV << " " << I.sample_weight;
     return os;
   }
