@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   ILK   - Tilburg University
   CLST  - Radboud University
   CLiPS - University of Antwerp
@@ -55,14 +55,17 @@
 #include "timbl/MBLClass.h"
 
 using namespace std;
+using namespace nlohmann;
 
 namespace Timbl {
 
   void MBLClass::fill_table(){
-    if ( tableFilled )
+    if ( tableFilled ){
       return;
-    else
+    }
+    else {
       tableFilled = true;
+    }
     //cerr << "fill table() for " << (void*)this << endl;
     bool stat =
       Options.Add( new IntegerOption( "FLENGTH",
@@ -151,12 +154,14 @@ namespace Timbl {
   }
 
   void MBLClass::InvalidMessage(void) const{
-    if ( err_count++ == 1 )
+    if ( err_count++ == 1 ){
       Warning( "A preceding error prevents any operation on this "
 	       "Timbl Object\n"
 	       "other experiments might not be influenced" );
-    else
+    }
+    else {
       Warning( "This Experiment is invalid due to errors" );
+    }
   }
 
   bool MBLClass::SetOption( const string& line ){
@@ -190,6 +195,7 @@ namespace Timbl {
     is_copy = false;
     is_synced = false;
     sock_os = 0;
+    sock_is_json = false;
     Targets   = NULL;
     err_count = 0;
     MBL_init = false;
@@ -251,9 +257,11 @@ namespace Timbl {
       verbosity          = m.verbosity;
       do_exact_match     = m.do_exact_match;
       sock_os            = 0;
+      sock_is_json       = false;
       globalMetricOption = m.globalMetricOption;
-      if ( m.GlobalMetric )
+      if ( m.GlobalMetric ){
 	GlobalMetric     = getMetricClass( m.GlobalMetric->type() );
+      }
       UserOptions        = m.UserOptions;
       mvd_threshold      = m.mvd_threshold;
       num_of_neighbors   = m.num_of_neighbors;
@@ -277,10 +285,12 @@ namespace Timbl {
       PermFeatures = m.PermFeatures;
       for ( unsigned int i=0; i < Features.size(); ++i ){
 	Features[i] = new Feature( *m.Features[i] );
-	if ( m.PermFeatures[i] )
+	if ( m.PermFeatures[i] ) {
 	  PermFeatures[i] = Features[permutation[i]];
-	else
+	}
+	else {
 	  PermFeatures[i] = 0;
+	}
       }
       Targets   = m.Targets;
       err_count = 0;
@@ -332,49 +342,82 @@ namespace Timbl {
 #pragma omp critical
     {
       // Info NEVER to socket !
-      if ( exp_name != "" )
+      if ( exp_name != "" ){
 	*mylog << "-" << exp_name << "-" << out_line << endl;
-      else
+      }
+      else {
 	*mylog << out_line << endl;
+      }
     }
   }
 
   void MBLClass::Warning( const string& out_line ) const {
 #pragma omp critical
     {
-      if ( sock_os )
-	*sock_os << "ERROR { " << out_line << " }" << endl;
+      if ( sock_os ){
+	if ( sock_is_json ){
+	  json out_json;
+	  out_json["status"] = "error";
+	  out_json["message"] = out_line;
+	  last_error = out_json;
+	}
+	else {
+	  *sock_os << "ERROR { " << out_line << " }" << endl;
+	}
+      }
       else {
-	if ( exp_name != "" )
+	if ( exp_name != "" ){
 	  *myerr << "Warning:-" << exp_name << "-" << out_line << endl;
-	else
-	*myerr << "Warning: " << out_line << endl;
+	}
+	else {
+	  *myerr << "Warning: " << out_line << endl;
+	}
       }
     }
   }
 
   void MBLClass::Error( const string& out_line ) const {
-    if ( sock_os )
-      *sock_os << "ERROR { " << out_line << " }"  << endl;
+    if ( sock_os ){
+      if ( sock_is_json ){
+	json out_json;
+	out_json["status"] = "error";
+	out_json["message"] = out_line;
+	last_error = out_json;
+      }
+      else {
+	*sock_os << "ERROR { " << out_line << " }"  << endl;
+      }
+    }
     else {
-      if ( exp_name != "" )
+      if ( exp_name != "" ){
 	*myerr << "Error:-" << exp_name << "-" << out_line << endl;
-      else
+      }
+      else {
 	*myerr << "Error: " << out_line << endl;
+      }
     }
     err_count++;
   }
 
   void MBLClass::FatalError( const string& out_line ) const {
-    if ( sock_os )
-      *sock_os << "ERROR { " << out_line << " }" << endl;
+    if ( sock_os ){
+      if ( sock_is_json ){
+	json out_json;
+	out_json["status"] = "error";
+	out_json["message"] = out_line;
+	last_error = out_json;
+      }
+      else {
+	*sock_os << "ERROR { " << out_line << " }" << endl;
+      }
+    }
     else {
-      if ( exp_name != "" )
-	*myerr << "-" << exp_name << "-";
-      if ( exp_name != "" )
+      if ( exp_name != "" ){
 	*myerr << "FatalError:-" << exp_name << "-" << out_line << endl;
-      else
+      }
+      else {
 	*myerr << "FatalError: " << out_line << endl;
+      }
       throw( runtime_error("Stopped") );
     }
   }
@@ -393,13 +436,14 @@ namespace Timbl {
     return true;
   }
 
-  bool MBLClass::connectToSocket( ostream *ss ){
+  bool MBLClass::connectToSocket( ostream *ss, bool is_json ){
     if ( sock_os ){
       throw( logic_error( "connectToSocket:: already connected!" ) );
     }
     else {
       sock_os = ss;
       if ( sock_os && sock_os->good() ){
+	sock_is_json = is_json;
 	return true;
       }
       else {
@@ -426,9 +470,32 @@ namespace Timbl {
     return result;
   }
 
+  json MBLClass::settings_to_JSON() const{
+    ostringstream tmp;
+    Options.Show_Settings( tmp );
+    vector<string> lines = TiCC::split_at( tmp.str(), "\n" );
+    json result;
+    json arr = json::array();
+    for ( const auto& line : lines ){
+      vector<string> parts = TiCC::split_at( line, ":" );
+      if ( parts.size() ==2 ){
+	string tag = TiCC::trim( parts[0] );
+	string val = TiCC::trim( parts[1] );
+	// a lot of values are integers, some float's
+	// in fact they should be added as such, not as strings....
+	json element;
+	element[tag] = val;
+	arr.push_back( element );
+      }
+    }
+    result["settings"] = arr;
+    return result;
+  }
+
   bool MBLClass::ShowWeights( ostream &os ) const {
-    if ( ExpInvalid() )
+    if ( ExpInvalid() ){
       return false;
+    }
     else {
       int OldPrec = os.precision(DBL_DIG);
       size_t pos = 0;
@@ -460,8 +527,9 @@ namespace Timbl {
       for ( size_t k=0; k < num_of_features; ++k ){
 	size_t Max = 0;
 	for ( size_t m=1; m < num_of_features; ++m ){
-	  if ( WR[m] > WR[Max] )
+	  if ( WR[m] > WR[Max] ){
 	    Max = m;
+	  }
 	}
 	WR[Max] = -1;
 	permutation[k] = Max;
@@ -586,8 +654,9 @@ namespace Timbl {
 	ostr.setf(ios::right, ios::adjustfield);
 	ostr << number << " @ ";
       }
-      else
+      else {
 	ostr << "        ";
+      }
       ostr << TiCC::Timer::now();
       Info( ostr.str() );
     }
@@ -595,9 +664,10 @@ namespace Timbl {
 
   void MBLClass::InitWeights(void){
     for ( auto const& feat : Features ){
-      if ( feat->Ignore() )
+      if ( feat->Ignore() ){
 	feat->SetWeight( 0.0 );
-      else
+      }
+      else {
 	switch ( Weighting ){
 	case IG_w:
 	  feat->SetWeight( feat->InfoGain() );
@@ -625,27 +695,30 @@ namespace Timbl {
 		      TiCC::toString( Weighting ) );
 	  break;
 	}
+      }
     }
   }
 
   void MBLClass::diverseWeights(void){
     double minW = DBL_MAX;
     for ( auto const& feat : Features ){
-      if ( feat->Ignore() )
+      if ( feat->Ignore() ){
 	continue;
+      }
       if ( feat->Weight() < minW ){
 	minW =  feat->Weight();
       }
     }
     for ( auto const& feat : Features ){
-      if ( feat->Ignore() )
+      if ( feat->Ignore() ){
 	continue;
+      }
       feat->SetWeight( (feat->Weight() - minW ) + Epsilon );
     }
   }
 
   void MBLClass::default_order(){
-    if ( TreeOrder == UnknownOrdening )
+    if ( TreeOrder == UnknownOrdening ){
       switch ( Weighting ){
       case GR_w:
 	TreeOrder = GROrder;
@@ -673,6 +746,7 @@ namespace Timbl {
 		    TiCC::toString( Weighting ) );
 	break;
       }
+    }
   }
 
   void MBLClass::set_order(){
@@ -738,13 +812,16 @@ namespace Timbl {
       ++i;
     }
     calculatePermutation( Order );
-    if ( !Verbosity(SILENT) )
+    if ( !Verbosity(SILENT) ){
       writePermutation( *mylog );
+    }
     for ( size_t j=0; j < num_of_features; ++j ){
-      if ( j < effective_feats )
+      if ( j < effective_feats ){
 	PermFeatures[j] = Features[permutation[j]];
-      else
+      }
+      else {
 	PermFeatures[j] = NULL;
+      }
     }
   }
 
@@ -763,9 +840,10 @@ namespace Timbl {
       }
       ++m;
     }
-    if ( TotalCount )
+    if ( TotalCount ){
       os << "Total Size of value-matrices " << TotalCount << " Bytes "
 	 << endl << endl;
+    }
   }
 
   bool MBLClass::readMatrices( istream& is ){
@@ -774,13 +852,16 @@ namespace Timbl {
     bool anything = false;
     while ( getline( is, line ) ){
       line = TiCC::trim( line );
-      if ( line.empty() )
+      if ( line.empty() ){
 	continue;
+      }
       if ( line.compare( 0, 7, "Feature" ) != 0 ){
-	if ( skip )
+	if ( skip ){
 	  continue;
-	else
+	}
+	else {
 	  return false;
+	}
       }
       else {
 	skip = false;
@@ -792,8 +873,9 @@ namespace Timbl {
 	  FatalError( "no feature index found in the inputfile" );
 	}
 	else {
-	  if ( pos == string::npos )
+	  if ( pos == string::npos ){
 	    line = "";
+	  }
 	  else {
 	    line = TiCC::trim( line.substr( pos ) );
 	  }
@@ -804,8 +886,9 @@ namespace Timbl {
 		       + " use -m commandline option to set metrics" );
 	      skip = true;
 	    }
-	    else if ( !Features[num-1]->fill_matrix( is ) )
+	    else if ( !Features[num-1]->fill_matrix( is ) ){
 	      return false;
+	    }
 	    else {
 	      Info( "read ValueMatrix for feature " + nums );
 	      anything = true;
@@ -916,8 +999,9 @@ namespace Timbl {
 
 
   bool MBLClass::writeArrays( ostream& os ) {
-    if ( ExpInvalid() )
+    if ( ExpInvalid() ){
       return false;
+    }
     else if ( !initProbabilityArrays( false ) ){
       Warning( "couldn't Calculate probability Arrays's" );
       return false;
@@ -930,8 +1014,9 @@ namespace Timbl {
       while ( it != Targets->ValuesArray.end() ){
 	os << (TargetValue *)*it;
 	++it;
-	if ( it != Targets->ValuesArray.end() )
+	if ( it != Targets->ValuesArray.end() ){
 	  os << ",";
+	}
       }
       os << "." << endl << endl;
       size_t pos = 0;
@@ -958,8 +1043,9 @@ namespace Timbl {
     for ( const auto& feat : Features ){
       if ( !feat->Ignore() &&
 	   !feat->isNumerical() ) {
-	if ( !feat->AllocSparseArrays( Dim ) )
+	if ( !feat->AllocSparseArrays( Dim ) ){
 	  return false;
+	}
       }
     }
     return true;
@@ -1036,8 +1122,10 @@ namespace Timbl {
       // Now add the Feature values.
       for ( size_t i = 0; i < num_of_features; ++i ){
 	// when learning, no need to bother about Permutation
-	if ( Features[i]->Ignore() ) // but this might happen, take care!
+	if ( Features[i]->Ignore() ) {
+	  // but this might happen, take care!
 	  CurrInst.FV[i] = NULL;
+	}
 	else {
 	  // Add it to the Instance.
 	  CurrInst.FV[i] = Features[i]->add_value( ChopInput->getField(i),
@@ -1090,8 +1178,9 @@ namespace Timbl {
     }
     if ( ( phase != TestWords ) && doSamples() ){
       double exW = ChopInput->getExW();
-      if ( exW < 0 )
+      if ( exW < 0 ){
 	exW = 1.0;
+      }
       CurrInst.ExemplarWeight( exW );
     }
     return &CurrInst;
@@ -1132,8 +1221,9 @@ namespace Timbl {
 	      os.setf(ios::right, ios::adjustfield);
 	      os << setw(7) << feat->EffectiveValues()
 		 << "\t" << feat->StandardDeviation();
-	      if ( feat->isNumerical() )
+	      if ( feat->isNumerical() ){
 		os << " NUMERIC";
+	      }
 	      os << endl;
 	    }
 	  }
@@ -1156,8 +1246,9 @@ namespace Timbl {
 		 << "\t" << feat->SharedVariance()
 		 << "\t" << feat->InfoGain()
 		 << "\t" << feat->GainRatio();
-	      if ( feat->isNumerical() )
+	      if ( feat->isNumerical() ){
 		os << " NUMERIC";
+	      }
 	      os << endl;
 	    }
 	  }
@@ -1178,8 +1269,9 @@ namespace Timbl {
 	      os << setw(7) << feat->EffectiveValues()
 		 << "\t" << feat->InfoGain()
 		 << "\t" << feat->GainRatio();
-	      if ( feat->isNumerical() )
+	      if ( feat->isNumerical() ){
 		os << " NUMERIC";
+	      }
 	      os << endl;
 	    }
 	  }
@@ -1209,10 +1301,12 @@ namespace Timbl {
 	  for ( const auto& feat : Features ){
 	    os.precision(DBL_DIG);
 	    os << ++pos << "\t";
-	    if ( feat->Ignore() )
+	    if ( feat->Ignore() ){
 	      os << "Ignore" << endl;
-	    else
+	    }
+	    else {
 	      os << feat->StandardDeviation() << endl;
+	    }
 	  }
 	  os << "#" << endl;
 	}
@@ -1223,10 +1317,12 @@ namespace Timbl {
 	  for (  const auto& feat : Features ){
 	    os.precision(DBL_DIG);
 	    os << ++pos << "\t";
-	    if ( feat->Ignore() )
+	    if ( feat->Ignore() ){
 	      os << "Ignore" << endl;
-	    else
+	    }
+	    else {
 	      os << 1.0 << endl;
+	    }
 	  }
 	  os << "#" << endl;
 	  os << "# " << TiCC::toString( GR_w ) << endl;
@@ -1235,10 +1331,12 @@ namespace Timbl {
 	  for (  const auto& feat : Features ){
 	    os.precision(DBL_DIG);
 	    os << ++pos << "\t";
-	    if ( feat->Ignore() )
+	    if ( feat->Ignore() ){
 	      os << "Ignore" << endl;
-	    else
+	    }
+	    else {
 	      os << feat->GainRatio() << endl;
+	    }
 	  }
 	  os << "#" << endl;
 	  os << "# " << TiCC::toString( IG_w ) << endl;
@@ -1247,10 +1345,12 @@ namespace Timbl {
 	  for (  const auto& feat : Features ){
 	    os.precision(DBL_DIG);
 	    os << ++pos << "\t";
-	    if ( feat->Ignore() )
+	    if ( feat->Ignore() ){
 	      os << "Ignore" << endl;
-	    else
+	    }
+	    else {
 	      os << feat->InfoGain() << endl;
+	    }
 	  }
 	  if ( need_all_weights ){
 	    os << "#" << endl;
@@ -1260,10 +1360,12 @@ namespace Timbl {
 	    for (  const auto& feat : Features ){
 	      os.precision(DBL_DIG);
 	      os << ++pos << "\t";
-	      if ( feat->Ignore() )
+	      if ( feat->Ignore() ){
 		os << "Ignore" << endl;
-	      else
+	      }
+	      else {
 		os << feat->SharedVariance() << endl;
+	      }
 	    }
 	    os << "#" << endl;
 	    os << "# " << TiCC::toString( X2_w ) << endl;
@@ -1272,10 +1374,12 @@ namespace Timbl {
 	    for (  const auto& feat : Features ){
 	      os.precision(DBL_DIG);
 	      os << ++pos << "\t";
-	      if ( feat->Ignore() )
+	      if ( feat->Ignore() ){
 		os << "Ignore" << endl;
-	      else
+	      }
+	      else {
 		os << feat->ChiSquare() << endl;
+	      }
 	    }
 	    os << "#" << endl;
 	  }
@@ -1288,10 +1392,10 @@ namespace Timbl {
   }
 
   bool MBLClass::read_the_vals( istream& is ){
-    bool result = true;
     bool *done = new bool[num_of_features];
-    for ( size_t i=0; i < num_of_features; ++i )
+    for ( size_t i=0; i < num_of_features; ++i ){
       done[i] = false;
+    }
     string Buffer;
     while ( getline( is, Buffer) ){
       if ( !Buffer.empty() ){
@@ -1324,30 +1428,32 @@ namespace Timbl {
 	      }
 	      else {
 		Features[i_f-1]->SetWeight( w );
-		if ( Features[i_f-1]->Ignore() )
+		if ( Features[i_f-1]->Ignore() ){
 		  Warning( "in weightsfile, "
 			   "Feature " + vals[0] + " has value: " +
 			   TiCC::toString<double>( w ) +
 			   " assigned, but will be ignored" );
+		}
 	      }
 	    }
 	    else {
 	      Features[i_f-1]->SetWeight( 0.0 );
-	      if ( !Features[i_f-1]->Ignore() )
+	      if ( !Features[i_f-1]->Ignore() ){
 		Warning( "in weightsfile, Feature " + vals[0] +
 			 " has value: 'Ignore', we will use: 0.0 " );
+	      }
 	    }
 	  }
 	}
       }
     }
-    if ( result ){
-      for ( size_t j=0; j < num_of_features; ++j )
-	if ( !done[j] ) {
-	  Error( "in weightsfile, Feature index " + TiCC::toString<size_t>(j+1) +
-		 " is not mentioned" );
-	  result = false;
-	}
+    bool result = true;
+    for ( size_t j=0; j < num_of_features; ++j ){
+      if ( !done[j] ) {
+	Error( "in weightsfile, Feature index " + TiCC::toString<size_t>(j+1) +
+	       " is not mentioned" );
+	result = false;
+      }
     }
     delete [] done;
     return result;
@@ -1361,15 +1467,17 @@ namespace Timbl {
       while( getline( is, Buffer ) ) {
 	// A comment starts with '#'
 	//
-	if ( Buffer.empty() )
+	if ( Buffer.empty() ){
 	  continue;
+	}
 	else {
 	  if ( Buffer[0] == '#'){
 	    vector<string> vals;
 	    if ( TiCC::split_at( Buffer, vals, " " ) == 2  ){
 	      WeightType tmp_w = Unknown_w;
-	      if ( !TiCC::stringTo<WeightType>( vals[1], tmp_w ) )
+	      if ( !TiCC::stringTo<WeightType>( vals[1], tmp_w ) ){
 		continue;
+	      }
 	      else {
 		old_style = false;
 		if ( tmp_w == wanted ){
@@ -1441,8 +1549,9 @@ namespace Timbl {
       while ( it != Targets->ValuesArray.end() ){
 	double Ratio = (*it)->ValFreq() /
 	  (double)totval;
-	if ( Ratio > 0 )
+	if ( Ratio > 0 ){
 	  Entropy += Ratio * Log2(Ratio);
+	}
 	++it;
       }
       DBEntropy = fabs(-Entropy);
@@ -1454,8 +1563,9 @@ namespace Timbl {
     bool nothing_changed = true;
     for ( size_t g = 0; g < num_of_features; ++g ) {
       feat_status[g] = Unknown;
-      if ( Features[g]->Ignore() )
+      if ( Features[g]->Ignore() ){
 	continue;
+      }
       bool metricChanged = false;
       MetricType TmpMetricType = UserOptions[g+1];
       metricClass *tmpMetric = getMetricClass( TmpMetricType );
@@ -1475,8 +1585,9 @@ namespace Timbl {
 	  }
 	}
       }
-      else if ( Features[g]->ValuesArray.size() == 1 )
+      else if ( Features[g]->ValuesArray.size() == 1 ){
 	feat_status[g] = Singleton;
+      }
       delete tmpMetric;
       if ( always || realy_first ){
 	bool isRead;
@@ -1492,8 +1603,9 @@ namespace Timbl {
 	}
 	metricChanged = !Features[g]->setMetricType(TmpMetricType);
       }
-      if ( metricChanged )
+      if ( metricChanged ){
 	nothing_changed = false;
+      }
     } // end g
     if ( ( CurrentWeighting() == SD_w ||
 	   GlobalMetric->isSimilarityMetric() )
@@ -1509,25 +1621,30 @@ namespace Timbl {
 	    ostr1 << "The following feature(s) have non numeric value: ";
 	    first = false;
 	  }
-	  else
+	  else {
 	    ostr1 << ", ";
+	  }
 	  size_t n = ff;
 	  while ( ff < num_of_features-1 &&
-		  feat_status[ff+1] == NotNumeric )
-	    ff++;
+		  feat_status[ff+1] == NotNumeric ){
+	    ++ff;
+	  }
 	  if ( n != ff ){
 	    ostr1 << n+1 << "-" << ff+1;
 	  }
-	  else
+	  else {
 	    ostr1 << ff+1;
+	  }
 	}
       }
       if ( !first  ){
 	Error( ostr1.str() );
-	if ( GlobalMetric->isSimilarityMetric() )
+	if ( GlobalMetric->isSimilarityMetric() ){
 	  Error( "Therefore InnerProduct/Cosine operations are impossible" );
-	else
+	}
+	else {
 	  Error( "Therefore " + TiCC::toString(CurrentWeighting()) + " weighting is impossible" );
+	}
 	return;
       }
     }
@@ -1544,41 +1661,47 @@ namespace Timbl {
 	    ostr1 << "The following feature(s) have only 1 value: ";
 	    first = false;
 	  }
-	  else
+	  else {
 	    ostr1 << ", ";
+	  }
 	  size_t n = ff;
 	  while ( ff < num_of_features-1 &&
 		  ( feat_status[ff+1] == Singleton ||
-		    feat_status[ff+1] == SingletonNumeric ) )
-	    ff++;
+		    feat_status[ff+1] == SingletonNumeric ) ){
+	    ++ff;
+	  }
 	  if ( n != ff ){
 	    ostr1 << n+1 << "-" << ff+1;
 	  }
-	  else
+	  else {
 	    ostr1 << ff+1;
+	  }
 	}
       }
       if ( !first && !is_copy ){
 	Warning( ostr1.str() );
       }
       first = true;
-      for ( size_t ff = 0; ff < num_of_features; ++ff )
+      for ( size_t ff = 0; ff < num_of_features; ++ff ){
 	if ( feat_status[ff] == NotNumeric ){
 	  if ( first ){
 	    ostr2 << "The following feature(s) contained non-numeric values and\nwill be treated as NON-Numeric: ";
 	    first = false;
 	  }
-	  else
+	  else {
 	    ostr2 << ", ";
+	  }
 	  size_t n = ff;
 	  while ( ff < num_of_features-1 &&
 		  feat_status[ff+1] == NotNumeric ) ff++;
 	  if ( n != ff ){
 	    ostr2 << n+1 << "-" << ff+1;
 	  }
-	  else
+	  else {
 	    ostr2 << ff+1;
+	  }
 	}
+      }
       if ( !first  ){
 	Warning( ostr2.str() );
       }
@@ -1586,8 +1709,9 @@ namespace Timbl {
     if ( always || realy_first ){
       for ( const auto& feat : Features ){
 	if ( Weighting != UserDefined_w ){
-	  if ( CurrentWeighting() == SD_w )
+	  if ( CurrentWeighting() == SD_w ){
 	    feat->StandardDeviationStatistics( );
+	  }
 	  else if ( feat->isNumerical() ){
 	    feat->NumStatistics( DBEntropy, Targets, Bin_Size,
 				 need_all_weights );
@@ -1612,17 +1736,20 @@ namespace Timbl {
       while ( it != Targets->ValuesArray.end() ){
 	os << (TargetValue *)*it;
 	++it;
-	if ( it != Targets->ValuesArray.end() )
+	if ( it != Targets->ValuesArray.end() ){
 	  os << ",";
+	}
       }
       os << "." << endl << endl;
       size_t pos = 0;
       for ( auto const& feat : Features ){
 	os << "a" << ++pos << ": ";
-	if ( feat->Ignore() )
+	if ( feat->Ignore() ){
 	  os << "Ignore" << endl;
-	else if ( feat->isNumerical() )
+	}
+	else if ( feat->isNumerical() ){
 	  os << "Numeric" << endl;
+	}
 	else {
 	  // Loop over the values.
 	  //
@@ -1630,8 +1757,9 @@ namespace Timbl {
 	  while( it2 != feat->ValuesArray.end() ){
 	    os << (FeatureValue *)*it2;
 	    ++it2;
-	    if ( it2 != feat->ValuesArray.end() )
+	    if ( it2 != feat->ValuesArray.end() ){
 	      os << ",";
+	    }
 	  }
 	  os << "." << endl;
 	}
@@ -1688,49 +1816,62 @@ namespace Timbl {
 				   size_t Size ) const {
     string result;
     Instance inst( Size );
-    for ( size_t i=0; i< OffSet; ++i )
+    for ( size_t i=0; i< OffSet; ++i ){
       inst.FV[i] = OrgFV[i];
-    for ( size_t j=OffSet; j< Size; ++j )
+    }
+    for ( size_t j=OffSet; j< Size; ++j ){
       inst.FV[j] = RedFV[j-OffSet];
+    }
     size_t *InvPerm = new size_t[num_of_features];
-    for ( size_t i=0; i< num_of_features; ++i )
+    for ( size_t i=0; i< num_of_features; ++i ){
       InvPerm[permutation[i]] = i;
+    }
     for ( size_t j=0; j< num_of_features; ++j ){
       switch ( input_format ) {
       case C4_5:
 	// fall through
       case ARFF:
-	if ( Features[j]->Ignore() )
+	if ( Features[j]->Ignore() ){
 	  result += "-*-,";
-	else
+	}
+	else {
 	  result += inst.FV[InvPerm[j]]->Name() + ",";
+	}
 	break;
       case Sparse:
-	if ( inst.FV[InvPerm[j]]->Name() != DefaultSparseString )
+	if ( inst.FV[InvPerm[j]]->Name() != DefaultSparseString ){
 	  result += string("(")  + TiCC::toString<size_t>(j+1) + ","
 	    + CodeToStr( inst.FV[InvPerm[j]]->Name() ) + ")";
+	}
 	break;
       case SparseBin:
-	if ( inst.FV[InvPerm[j]]->Name()[0] == '1' )
+	if ( inst.FV[InvPerm[j]]->Name()[0] == '1' ){
 	  result += TiCC::toString<size_t>( j+1 ) + ",";
+	}
 	break;
       case Columns:
-	if ( Features[j]->Ignore() )
+	if ( Features[j]->Ignore() ){
 	  result += "-*- ";
-	else
+	}
+	else {
 	  result += inst.FV[InvPerm[j]]->Name() + " ";
+	}
 	break;
       case Tabbed:
-	if ( Features[j]->Ignore() )
+	if ( Features[j]->Ignore() ){
 	  result += "-*- ";
-	else
+	}
+	else {
 	  result += inst.FV[InvPerm[j]]->Name() + "\t";
+	}
 	break;
       default:
-	if ( Features[j]->Ignore() )
+	if ( Features[j]->Ignore() ){
 	  result += string( F_length, '*' );
-	else
+	}
+	else {
 	  result += inst.FV[InvPerm[j]]->Name();
+	}
 	break;
       }
     }
@@ -1757,8 +1898,9 @@ namespace Timbl {
     Vfield *Bpnt = NULL;
     if ( best_distrib ){
       lastpos = best_distrib->begin();
-      if ( lastpos != best_distrib->end() )
+      if ( lastpos != best_distrib->end() ){
 	Bpnt = lastpos->second;
+      }
     }
     size_t CurPos = 0;
     while ( Bpnt ) {
@@ -1860,8 +2002,9 @@ namespace Timbl {
 	  //	  cerr << "Ok add " << best_distrib << "at distance " << Distance << endl;
 	  Threshold = bestArray.addResult( Distance, best_distrib, origI );
 	  //	  cerr << "BA = " << bestArray << endl;
-	  if ( do_silly_testing )
+	  if ( do_silly_testing ){
 	    Threshold = DBL_MAX;
+	  }
 	}
 	else {
 	  Error( "DISTANCE == " + TiCC::toString<double>(Distance) );
@@ -1883,8 +2026,9 @@ namespace Timbl {
 	  //	  cerr << "na next test, curpos=" << CurPos << "-" << TiCC::toString(CurrentFV) << endl;
 	  break;
 	}
-	if ( pos == 0 )
+	if ( pos == 0 ){
 	  break;
+	}
 	--pos;
       }
     }
@@ -1947,18 +2091,21 @@ namespace Timbl {
       test_instance_ex( Inst, SubTree, level );
     }
     else {
-      if ( GlobalMetric->isSimilarityMetric( ) )
+      if ( GlobalMetric->isSimilarityMetric( ) ){
 	test_instance_sim( Inst, SubTree, level );
-      else
+      }
+      else {
 	test_instance( Inst, SubTree, level );
+      }
     }
   }
 
   size_t MBLClass::countFeatures( const string& inBuffer,
 				  const InputFormatType IF ) const {
     size_t result = 0;
-    if ( IF == Sparse  || IF == SparseBin )
+    if ( IF == Sparse  || IF == SparseBin ){
       return num_of_features;
+    }
     else {
       try {
 	result = Chopper::countFeatures( inBuffer, IF, F_length,
@@ -1999,8 +2146,9 @@ namespace Timbl {
       }
       else if ( input_format != UnknownInputFormat ){
 	// The format is somehow already known, so use that
-	if ( input_format == SparseBin || input_format == Sparse )
+	if ( input_format == SparseBin || input_format == Sparse ){
 	  NumF = MaxFeatures;
+	}
 	else {
 	  if ( !getline( datafile, Buffer ) ) {
 	    Warning( "empty data file" );
@@ -2090,15 +2238,18 @@ namespace Timbl {
   }
 
   void MBLClass::Initialize( size_t n ){
-    if ( n > 0 )
+    if ( n > 0 ) {
       num_of_features = n;
+    }
     // Allocate memory. Will be reused again and again ....
     //
-    if ( target_pos == std::numeric_limits<size_t>::max() )
+    if ( target_pos == std::numeric_limits<size_t>::max() ){
       target_pos = num_of_features; // the default
-    else if ( target_pos > num_of_features )
+    }
+    else if ( target_pos > num_of_features ){
       FatalError( "Initialize: TARGET_POS cannot exceed NUM_OF_FEATURES+1 " +
 		  TiCC::toString<size_t>( num_of_features+1 ) );
+    }
     Features.resize(num_of_features,NULL);
     PermFeatures.resize(num_of_features,NULL);
     FeatureStrings = new Hash::StringHash(); // all features share the same hash
