@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   ILK   - Tilburg University
   CLST  - Radboud University
   CLiPS - University of Antwerp
@@ -125,8 +125,9 @@ namespace Timbl {
 	  ++dis2;
 	}
       }
-      else
+      else {
 	break;
+      }
     }
     while ( dit2 != s.distances.end() ){
       distances.push_back( *dit2 );
@@ -139,8 +140,9 @@ namespace Timbl {
   double neighborSet::relativeWeight( const decayStruct *d,
 				      size_t k ) const{
     double result = 1.0;
-    if ( !d )
+    if ( !d ){
       return result;
+    }
     switch ( d->type() ){
     case Zero:
       break;
@@ -202,8 +204,9 @@ namespace Timbl {
   ostream& operator<<( ostream& os, const neighborSet& set ){
     for ( unsigned int i=0; i < set.size(); ++i ){
       os << "# k=" << i+1;
-      if ( set.showDistribution )
+      if ( set.showDistribution ){
 	os << "\t"  << set.distributions[i]->DistToStringW(0);
+      }
       if ( set.showDistance ){
 	int OldPrec = os.precision(DBL_DIG-1);
 	os.setf(ios::showpoint);
@@ -245,8 +248,9 @@ namespace Timbl {
   }
 
   ostream& operator<<( ostream& os, const decayStruct *dc ){
-    if ( dc )
+    if ( dc ){
       os << *dc;
+    }
     return os;
   }
 
